// *********************************************************************
// * Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)         *
// *                                                                   *
// * For the license terms see the file LICENCE, distributed           *
// * along with this software.                                         *
// *********************************************************************
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


#include "RunControl.h"


RunControl::RunControl() :
  m_running(false),
  m_startMicros(0),
  m_startMillis(0)
{
  //Nothing to do here, once all the class members are initialized.
}


void RunControl::start()
{
  m_running = true;
  m_startMicros = micros();
  m_startMillis = millis();
}


void RunControl::stop()
{
  m_running = false;
}


uint32_t RunControl::microsSinceStart()
{
  return micros() - m_startMicros;
}


uint32_t RunControl::millisSinceStart()
{
  return millis() - m_startMillis;
}


void RunControl::listen()
{
if (Serial.available()) {
    byte opcode = Serial.read();
    if (opcode == OP_CODE_START_RUN) {
      start();
    }
    else if (opcode == OP_CODE_STOP_RUN) {
      stop();
    }
  }
}


uint8_t RunControl::echo()
{
  if (Serial.available()) {
    byte opcode = Serial.read();
    if (opcode == OP_CODE_START_RUN) {
      start();
    }
    else if (opcode == OP_CODE_STOP_RUN) {
      stop();
    }
    return opcode;
  }
  return OP_CODE_NO_OP;
}
