//-*- Mode:c -*-
// *********************************************************************
// * Copyright (C) 2012 Carmelo Sgro (carmelo.sgro@pi.infn.it)         *
// * Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)         *
// *                                                                   *
// * For the license terms see the file LICENCE, distributed           *
// * along with this software.                                         *
// *********************************************************************
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


#include "RunControl.h"
#include "shield_lab1.h"


/*
  Put documentation here.
*/


/*
  Definition of the interrupt pins.

  Most Arduino boards have two external interrupts: numbers 0 (on digital pin 2)
  and 1 (on digital pin 3); this is all we are supporting at this time.
 */
#define SKETCH_ID SKETCH_ID_DIGITAL_TIMER
#define SKETCH_VERSION 1
#define INTERRUPT_PIN_0 2
#define INTERRUPT_PIN_1 3


/*
  Initialize global variables.
*/
RunControl RUN_CONTROL;
uint32_t _timestamp;
uint32_t _state;


/*
  setup() implementation.

  We basically handshake with the PC and then attach the interrupt service
  routines if needed.
 */
void setup() {
  setupBoard();
  handshake(SKETCH_ID, SKETCH_VERSION);
  uint8_t mode;
  mode = sreadcmd8(OP_CODE_SELECT_INTERRUPT_MODE);
  if (mode) {
    attachInterrupt(0, intSvcRoutine0, mode);
  }
  mode = sreadcmd8(OP_CODE_SELECT_INTERRUPT_MODE);
  if (mode) {
    attachInterrupt(1, intSvcRoutine1, mode);
  }
}


/*
  loop() implementation.
  
  Here we just listen to the serial port for the RunControl to be started or
  stopped.
 */
void loop() {
  RUN_CONTROL.listen();
}


/*
  Interrupt service routine on interrupt 0.

  If the RunControl is running, latch the time and the state of INTERRUPT_PIN_0
  and write the stuff to the serial port.
 */
void intSvcRoutine0() {
  if (RUN_CONTROL.running()) {
    _timestamp = RUN_CONTROL.microsSinceStart();
    _state = digitalRead(INTERRUPT_PIN_0);
    swriteDigitalTransition(INTERRUPT_PIN_0, _state, _timestamp);
  }
}


/*
  Interrupt service routine on interrupt 1.

  If the RunControl is running, latch the time and the state of INTERRUPT_PIN_1
  and write the stuff to the serial port.
 */
void intSvcRoutine1() {
  if (RUN_CONTROL.running()) {
    _timestamp = RUN_CONTROL.microsSinceStart();
    _state = digitalRead(INTERRUPT_PIN_1);
    swriteDigitalTransition(INTERRUPT_PIN_1, _state, _timestamp);
  }
}
